[TOC]

注意,涉及到的安装都是`amd64`或者`x86_64`
## Docker 安装(在线)
### Ubuntu

```shell
curl -fsSL https://test.docker.com -o test-docker.sh
sudo sh test-docker.sh
```

可能需要卸载老版本docker

```sh
sudo apt-get remove docker docker-engine docker.io containerd runc
```

### Debian

```shell
curl -fsSL https://get.docker.com -o get-docker.sh
sudo sh get-docker.sh
```

可能需要卸载老版本docker

```shell
sudo apt-get remove docker docker-engine docker.io containerd runc
```

### CentOS

```shell
curl -fsSL https://get.docker.com | bash -s docker --mirror Aliyun
```

可能需要卸载老版本docker

```shell
sudo yum remove docker \
	docker-client \
	docker-client-latest \
	docker-common \
	docker-latest \
	docker-latest-logrotate \
	docker-logrotate \
	docker-engine
```

## Docker安装(离线)

保存脚本为sh文件,到`https://download.docker.com/linux/`下载需要的docker版本,并运行脚本(传递docker安装包文件路径为第一个参数)

```shell
# 检查命令
if [ "$#" -lt 1 ]; then
    echo "错误：请传入一个参数,参数为docker安装包文件路径"
    exit 1
fi
if command -v "docker" >/dev/null 2>&1; then
    echo "docker 已经存在"
        exit 1
fi
# 检查文件
if [ -f "$1" ]; then
        tar -zxf $1
        cp docker/* /usr/bin
else
        echo "$1不存在"
        exit 1
fi
# 创建.service文件
cat > /etc/systemd/system/docker.service << EOF
[Unit]
Description=Docker Application Container Engine
Documentation=https://docs.docker.com
After=network-online.target firewalld.service
Wants=network-online.target
[Service]
Type=notify
ExecStart=/usr/bin/dockerd
ExecReload=/bin/kill -s HUP \$MAINPID
LimitNOFILE=infinity
LimitNPROC=infinity
TimeoutStartSec=0
Delegate=yes
KillMode=process
Restart=on-failure
StartLimitBurst=3
StartLimitInterval=60s
[Install]
WantedBy=multi-user.target
EOF

# 赋权
chmod +x /etc/systemd/system/docker.service
systemctl daemon-reload
# 开机启动
systemctl enable docker.service
# 启动docker
systemctl start docker
# docker状态
systemctl status docker
```
顺便将其他用户添加到docker组，方便其他用户运行docker
```sh
su
sudo gpasswd -a username docker
newgrp docker

```

## Go安装

主要通过解压安装，自动配置环境变量

其中`GoLang_Package`可以在`https://golang.google.cn/dl/`获取指定版本和平台

使用root运行

```shell
# 压缩包url, 这里是linux amd64 1.20.6 版本
GoLang_Package="https://dl.google.com/go/go1.20.6.linux-amd64.tar.gz"
install_path="/usr/local/"
function install_go() {
	if ! command -v go &> /dev/null;then
		echo "安装go环境"
		curl -o "go.tmp.tar.gz" $GoLang_Package
		rm -rf ${install_path}/go
		tar -C $install_path -xzf "go.tmp.tar.gz"
		echo "export GOROOT=\"${install_path}/go\"" >> /etc/profile
		echo "export GOPATH=\$HOME/go" >> /etc/profile
		echo "export GOBIN=\$GOROOT/bin" >> /etc/profile
		echo "export PATH=\$PATH:\$GOBIN" >> /etc/profile
		rm "go.tmp.tar.gz"
		source /etc/profile
		echo "安装go环境完毕"
	else
		echo "Go已安装"
	fi
}
install_go
```

## Java 安装

JDK 可直接到镜像站中下载, 而不是Oracle

华为云镜像：`https://repo.huaweicloud.com/java/jdk/`

阿里云镜像：`https://developer.aliyun.com/mirror/`(通过搜索软件包获取jdk)

使用root运行

```shell
# 压缩包url 这里是jdk8
Java_Package="https://repo.huaweicloud.com/java/jdk/8u202-b08/jdk-8u202-linux-x64.tar.gz"
install_path="/usr/local"
function install_java() {
	if ! command -v java &> /dev/null;then
		echo "安装java环境"
		curl -o "java.tmp.tar.gz" $Java_Package
		rm -rf ${install_path}/java
		tar -C $install_path -xzf "java.tmp.tar.gz"
		echo "export JAVA_HOME=\"${install_path}/java\"" >> /etc/profile
		echo "export PATH=\$JAVA_HOME/bin:\$PATH" >> /etc/profile
		echo "export CLASSPATH=.:\$JAVA_HOME/lib/dt.jar:\$JAVA_HOME/lib/tools.jar" >> /etc/profile
		rm "java.tmp.tar.gz"
		source /etc/profile
		echo "安装java环境完毕"
	else
		echo "java已安装"
	fi
}
install_java
```

## docker-compose
这里是v2.11.1

```shell
wget https://github.com/docker/compose/releases/download/v2.11.1/docker-compose-linux-x86_64 -O "docker-compose"
mv docker-compose /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose
sudo ln -s /usr/local/bin/docker-compose /usr/bin/docker-compose
```